## Changelog 
### v0.1.0 (2024-06-13)
Initial release

- `pipeline` can be used to combine learning algorithms and query strategies into active learning pipelines
- `evaluation` provides tools to evaluate active learning pipelines
- `benchmark` monitors the performance of active learning pipelines over time and store results in a database

### v0.1.1 (2024-06-14)

- extra code for `tabnet` does no longer need to be included from the repo

### v0.1.2 (2024-07-10)

- added plotting functionality to `evaluation` to generate budget curves
- notebook in `docs` explains how to extract results from previously run experiments and plot budget curves